summaryrefslogtreecommitdiffstats
path: root/telecomm
diff options
context:
space:
mode:
authorSantos Cordon <santoscordon@google.com>2014-02-20 17:13:15 -0800
committerSantos Cordon <santoscordon@google.com>2014-02-21 12:41:33 -0800
commit1fe964d11e4446437f2688648f2ffe45617b82d6 (patch)
tree0d2264c2ca18f2876c382400e965ea6bc5712591 /telecomm
parent738bfa55f704fc90b2b33890601328cc1c6194b6 (diff)
downloadframeworks_base-1fe964d11e4446437f2688648f2ffe45617b82d6.zip
frameworks_base-1fe964d11e4446437f2688648f2ffe45617b82d6.tar.gz
frameworks_base-1fe964d11e4446437f2688648f2ffe45617b82d6.tar.bz2
Renaming intent to INCOMING_CALL.
Change-Id: I90ac30be5d8503f100deedf44f8d3bd18de3fa83
Diffstat (limited to 'telecomm')
-rw-r--r--telecomm/java/android/telecomm/TelecommConstants.java29
1 files changed, 10 insertions, 19 deletions
diff --git a/telecomm/java/android/telecomm/TelecommConstants.java b/telecomm/java/android/telecomm/TelecommConstants.java
index ebb855c..a5ef344 100644
--- a/telecomm/java/android/telecomm/TelecommConstants.java
+++ b/telecomm/java/android/telecomm/TelecommConstants.java
@@ -23,15 +23,13 @@ public final class TelecommConstants {
/**
* <p>Activity action: Starts the UI for handing an incoming call. This intent starts the
* in-call UI by notifying the Telecomm system that an incoming call exists for a specific call
- * service (see {@link android.telecomm.ICallService}). Telecomm reads the Intent extras to find
- * and bind to the appropriate {@link android.telecomm.ICallServiceProvider} and
- * {@link android.telecomm.ICallService} implementations which Telecomm will ultimately use to
- * control and get information about the call.</p>
+ * service (see {@link android.telecomm.CallService}). Telecomm reads the Intent extras to find
+ * and bind to the appropriate {@link android.telecomm.CallService} which Telecomm will
+ * ultimately use to control and get information about the call.</p>
*
- * <p>Input: get*Extra field {@link #EXTRA_CALL_SERVICE_PROVIDER} contains the component name
- * of the {@link android.telecomm.ICallServiceProvider} service Telecomm should bind to.
- * {@link #EXTRA_CALL_SERVICE_ID} contains a string-based identifier that Telecomm will pass to
- * {@link ICallServiceProvider#getCallService} to get the appropriate {@link ICallService}.</p>
+ * <p>Input: get*Extra field {@link #EXTRA_CALL_SERVICE} contains the component name
+ * of the {@link android.telecomm.CallService} that Telecomm should bind to. Telecomm will then
+ * ask the call service for more information about the call prior to showing any UI.
*
* TODO(santoscordon): Needs permissions.
* TODO(santoscordon): Consider moving this into a simple method call on a system service.
@@ -39,16 +37,9 @@ public final class TelecommConstants {
public static final String ACTION_INCOMING_CALL = "android.intent.action.INCOMING_CALL";
/**
* Extra for {@link #ACTION_INCOMING_CALL} that contains the component name of the call-service
* provider used by Telecomm to obtain the correct call service for the incoming call.
*/
- public static final String EXTRA_CALL_SERVICE_PROVIDER =
- "android.intent.extra.CALL_SERVICE_PROVIDER";
-
- /**
- * Extra for {@link #ACTION_INCOMING_CALL} that contains the String-based ID that Telecomm will
- * use to obtain the correct call service for the incoming call via
- * {@link android.telecomm.ICallServiceProvider#getCallService}.
- */
- public static final String EXTRA_CALL_SERVICE_ID = "android.intent.extra.CALL_SERVICE_ID";
+ public static final String EXTRA_CALL_SERVICE_DESCRIPTOR =
+ "android.intent.extra.CALL_SERVICE_DESCRIPTOR";
}
@@ -39,16 +37,9 @@ public final class TelecommConstants {
public static final String ACTION_INCOMING_CALL = "android.intent.action.INCOMING_CALL";
/**
- * Extra for {@link #ACTION_INCOMING_CALL} that contains the component name of the call-service
- * provider used by Telecomm to obtain the correct call service for the incoming call.
+ * Extra for {@link #ACTION_INCOMING_CALL} containing the {@link CallServiceDescriptor} that
+ * describes the call service to use for the incoming call.
*/